=====
petty
=====


.. image:: https://img.shields.io/pypi/v/petty.svg
        :target: https://pypi.python.org/pypi/petty

.. image:: https://readthedocs.org/projects/petty/badge/?version=latest
        :target: https://petty.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://img.shields.io/pypi/l/petty?color=green
        :alt: PyPI - License

methods that often use
